@@ -88,19 +88,11 @@ OC.L10N.register(
     "Cancel" : "Отказ",
     "Could not update preference" : "Предпочитанието не можа да се актуализира",
     "Mail settings" : "Настройки на пощата",
-    "Accounts" : "Профили",
-    "Add mail account" : "Добавяне на профил",
     "General" : "Общи",
+    "Add mail account" : "Добавяне на профил",
     "List" : "Списък",
-    "Newest" : "Най-новият",
-    "Oldest" : "Най-старият",
-    "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
-    "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
     "Register" : "Регистрация",
     "Shared with me" : "Споделено с мен",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
-    "Trusted senders" : "Доверени податели",
-    "Manage S/MIME certificates" : "Управление на S/MIME сертификати",
     "About" : "Относно",
     "Keyboard shortcuts" : "Бързи клавиши",
     "Compose new message" : "Създай ново съобщение",
@@ -567,6 +559,14 @@ OC.L10N.register(
     "The link leads to %s" : "Връзката води до %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ако не желаете да посетите тази страница, може да се върнете към <a href=\"%s\">Поща</a>.",
     "Continue to %s" : "Продължи към %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него."
+    "Put my text to the bottom of a reply instead of on top of it." : "Поставяне на моя текст в долната част на отговора, вместо над него.",
+    "Accounts" : "Профили",
+    "Newest" : "Най-новият",
+    "Oldest" : "Най-старият",
+    "Use Gravatar and favicon avatars" : "Използване на аватари тип Gravatar и favicon",
+    "Register as application for mail links" : "Регистрирайте се като приложение за пощенски връзки",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Разрешаване на приложението да събира данни за вашите взаимодействия. Въз основа на тези данни приложението ще се адаптира към вашите предпочитания. Данните ще се съхраняват само локално.",
+    "Trusted senders" : "Доверени податели",
+    "Manage S/MIME certificates" : "Управление на S/MIME сертификати"
 },
 "nplurals=2; plural=(n != 1);");
