@@ -18,7 +18,6 @@ OC.L10N.register(
     "SMTP Password" : "Ger-tremen SMTP",
     "Change name" : "Cheñch env",
     "Cancel" : "Nullañ",
-    "Accounts" : "Kontoù",
     "General" : "Hollek",
     "List" : "Roll",
     "Delete" : "Dilemel",
@@ -77,6 +76,7 @@ OC.L10N.register(
     "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
+    "Accounts" : "Kontoù"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
