@@ -110,48 +110,33 @@ OC.L10N.register(
     "Add alias" : "Tilføj alias",
     "Create alias" : "Opret alias",
     "Cancel" : "Annuller",
-    "Search in the body of messages in priority Inbox" : "Søg i hovedteksten i beskeder i prioritets indbakke ",
     "Activate" : "Aktivér",
-    "Mark as important" : "Markér som vigtig",
     "Remind about messages that require a reply but received none" : "Mind mig om beskeder som kræver et svar, men ikke har modtaget et",
-    "Use internal addresses" : "Anvend interne adresser",
     "Could not update preference" : "Præference kunne ikke opdateres",
     "Mail settings" : "Mail indstillinger",
-    "Accounts" : "Konti",
+    "General" : "Generelt",
     "Add mail account" : "Tilføj mail konto",
     "Settings for:" : "Indstillinger for:",
-    "General" : "Generelt",
     "Layout" : "Layout",
     "List" : "Liste",
+    "Vertical split" : "Vertikal opdeling",
     "Horizontal split" : "Horisontal opdeling",
     "Sorting" : "Sortering",
-    "Newest" : "Nyeste",
-    "Oldest" : "Ældste",
+    "Newest first" : "Nyeste først",
     "Show all messages in thread" : "Vis alle beskeder i tråde",
-    "Show only the selected message" : "Vis kun den valgte besked",
-    "Reply text position" : "Svartekst placering",
     "Search in body" : "Søg i body",
     "Gravatar settings" : "Gravatar indstillinger",
-    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
     "Mailto" : "Mail til",
-    "Register as application for mail links" : "Registrer som program til at åbne mail links",
     "Register" : "Register",
     "Text blocks" : "Tekstblokke",
-    "Create a new text block" : "Opret en ny tekstblok",
+    "New text block" : "Ny tekstblok",
     "Shared with me" : "Delt med mig",
     "Privacy and security" : "Privatliv og sikkerhed",
-    "Data collection consent" : "Dataindsamlingssamtykke",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
-    "Trusted senders" : "Betroede afsendere",
-    "Internal addresses" : "Interne adresser",
+    "Security" : "Sikkerhed",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhæv eksterne e-mailadresser ved at aktivere denne funktion. Håndter dine interne adresser og domæner, for at sikre at genkendte kontakter forbliver ikke markerede.",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
     "Mailvelope" : "Mailvelope",
-    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope er en browser udvidelse som giver mulighed for let OpenPGP kryptering og dekryptering til e-mails.",
     "Mailvelope is enabled for the current domain." : "Mailvelope er aktiveret for det aktuelle domæne.",
-    "Step 1: Install Mailvelope browser extension" : "Trin 1: Installer Mailvelope browser udvidelse",
-    "Step 2: Enable Mailvelope for the current domain" : "Trin 2: Aktiver Mailvelope for det aktuelle domæne",
     "About" : "Om",
     "Keyboard shortcuts" : "Tastaturgenveje",
     "Compose new message" : "Skriv en ny meddelelse",
@@ -164,7 +149,6 @@ OC.L10N.register(
     "Search" : "Søg",
     "Send" : "Send",
     "Refresh" : "Opdatér",
-    "New text block" : "Ny tekstblok",
     "Title of the text block" : "Titel på ny tekstblok",
     "Content of the text block" : "Indhold i tekstblok",
     "Ok" : "OK",
@@ -303,6 +287,7 @@ OC.L10N.register(
     "Mark as unread" : "Markér som ulæst",
     "Mark as read" : "Markér som læst",
     "Mark as unimportant" : "Markér som ikke vigtig",
+    "Mark as important" : "Markér som vigtig",
     "Report this bug" : "Rapporter denne fejl",
     "Event created" : "Begivenhed oprettet",
     "Could not create event" : "Begivenheden kunne ikke oprettes",
@@ -544,6 +529,7 @@ OC.L10N.register(
     "delete" : "Slet",
     "Edit" : "Redigér",
     "Message View Mode" : "Besked visningstilstand",
+    "Show only the selected message" : "Vis kun den valgte besked",
     "Reset" : "Nulstil",
     "Client ID" : "Klient ID",
     "Client secret" : "Klienthemmelighed",
@@ -603,8 +589,23 @@ OC.L10N.register(
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
+    "Search in the body of messages in priority Inbox" : "Søg i hovedteksten i beskeder i prioritets indbakke ",
     "Put my text to the bottom of a reply instead of on top of it." : "Sæt min tekst til bunden af et svar i stedet for oven på den.",
-    "Vertical split" : "Vertikal opdeling",
-    "Older" : "Ældre"
+    "Use internal addresses" : "Anvend interne adresser",
+    "Accounts" : "Konti",
+    "Newest" : "Nyeste",
+    "Oldest" : "Ældste",
+    "Reply text position" : "Svartekst placering",
+    "Use Gravatar and favicon avatars" : "Brug Gravatar og favicon avatarer",
+    "Register as application for mail links" : "Registrer som program til at åbne mail links",
+    "Create a new text block" : "Opret en ny tekstblok",
+    "Data collection consent" : "Dataindsamlingssamtykke",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillad, at appen indsamler data om dine interaktioner. Baseret på disse data vil appen tilpasse sig dine præferencer. Dataene gemmes kun lokalt.",
+    "Trusted senders" : "Betroede afsendere",
+    "Internal addresses" : "Interne adresser",
+    "Manage S/MIME certificates" : "Administrer S/MIME-certifikater",
+    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope er en browser udvidelse som giver mulighed for let OpenPGP kryptering og dekryptering til e-mails.",
+    "Step 1: Install Mailvelope browser extension" : "Trin 1: Installer Mailvelope browser udvidelse",
+    "Step 2: Enable Mailvelope for the current domain" : "Trin 2: Aktiver Mailvelope for det aktuelle domæne"
 },
 "nplurals=2; plural=(n != 1);");
