@@ -28,11 +28,12 @@ OC.L10N.register(
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Add mail account" : "Agregar cuenta de correo",
+    "Newest first" : "Más reciente primero",
+    "Oldest first" : "Más antiguo primero",
     "Register" : "Registrar",
+    "Security" : "Seguridad",
     "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
@@ -144,6 +145,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Accounts" : "Accounts",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
