@@ -87,18 +87,14 @@ OC.L10N.register(
     "Cancel" : "Cancelar",
     "Could not update preference" : "No se pudo actualizar la preferencia",
     "Mail settings" : "Configuración de correo",
-    "Accounts" : "Cuentas",
-    "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
+    "Add mail account" : "Agregar cuenta de correo",
+    "Appearance" : "Apariencia",
     "Sorting" : "Ordenar",
-    "Newest" : "Más recientes",
-    "Oldest" : "Más antiguos",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Register as application for mail links" : "Registrarse como aplicación para enlaces de correo",
+    "Newest first" : "Más reciente primero",
+    "Oldest first" : "Más antiguo primero",
     "Register" : "Registrar",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
-    "Trusted senders" : "Remitentes de confianza",
-    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
+    "Security" : "Seguridad",
     "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
@@ -583,6 +579,14 @@ OC.L10N.register(
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
     "Continue to %s" : "Continuar a %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Colocar mi texto en la parte inferior de una respuesta en lugar de en la parte superior."
+    "Put my text to the bottom of a reply instead of on top of it." : "Colocar mi texto en la parte inferior de una respuesta en lugar de en la parte superior.",
+    "Accounts" : "Cuentas",
+    "Newest" : "Más recientes",
+    "Oldest" : "Más antiguos",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Register as application for mail links" : "Registrarse como aplicación para enlaces de correo",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
+    "Trusted senders" : "Remitentes de confianza",
+    "Manage S/MIME certificates" : "Administrar certificados S/MIME"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
