@@ -61,14 +61,12 @@ OC.L10N.register(
     "Create alias" : "Crear alias",
     "Cancel" : "Cancelar",
     "Could not update preference" : "No se pudo actualizar la preferencia",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
-    "Register as application for mail links" : "Usar aplicación para abrir enlaces de correo",
+    "Add mail account" : "Agregar cuenta de correo",
+    "Newest first" : "Más reciente primero",
+    "Oldest first" : "Más antiguo primero",
     "Register" : "Registrar",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir a la app recolectar datos sobre sus interacciones. Basándose en estos datos, la app se adaptará mejor a sus preferencias. Estos datos sólo se almacenan localmente.",
-    "Trusted senders" : "Remitentes de confianza",
+    "Security" : "Seguridad",
     "About" : "Acerca",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
@@ -205,6 +203,11 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Ponga mi texto al final de la respuesta en vez de encima de ella."
+    "Put my text to the bottom of a reply instead of on top of it." : "Ponga mi texto al final de la respuesta en vez de encima de ella.",
+    "Accounts" : "Accounts",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Register as application for mail links" : "Usar aplicación para abrir enlaces de correo",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir a la app recolectar datos sobre sus interacciones. Basándose en estos datos, la app se adaptará mejor a sus preferencias. Estos datos sólo se almacenan localmente.",
+    "Trusted senders" : "Remitentes de confianza"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
