@@ -108,38 +108,29 @@ OC.L10N.register(
     "Add alias" : "Añadir alias",
     "Create alias" : "Crear alias",
     "Cancel" : "Cancelar",
-    "Search in the body of messages in priority Inbox" : "Busca en el cuerpo de los mensajes de la bandeja de entrada prioritaria",
     "Activate" : "Activar",
-    "Mark as important" : "Marcar como importante",
     "Remind about messages that require a reply but received none" : "Recordar mensajes que requieren una respuesta pero no han recibido ninguna",
-    "Use internal addresses" : "Usar direcciones internas",
     "Could not update preference" : "No se pudo actualizar la preferencia",
     "Mail settings" : "Configuración de correo",
-    "Accounts" : "Cuentas",
+    "General" : "General",
     "Add mail account" : "Agregar cuenta de correo",
     "Settings for:" : "Configuraciones para:",
-    "General" : "General",
+    "Appearance" : "Apariencia",
     "Layout" : "Disposición",
     "List" : "Lista",
+    "Vertical split" : "División vertical",
     "Horizontal split" : "División horizontal",
     "Sorting" : "Ordenando",
-    "Newest" : "Más recientes",
-    "Oldest" : "Más antiguo",
-    "Reply text position" : "Posisión de respuesta del texto",
+    "Newest first" : "Más reciente primero",
+    "Oldest first" : "Más antiguo primero",
     "Search in body" : "Buscar cuerpo",
     "Gravatar settings" : "Ajustes de Gravatar",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
     "Mailto" : "Mailto",
-    "Register as application for mail links" : "Registrar como aplicación para enlaces de correo electrónico",
     "Register" : "Registrar",
     "Privacy and security" : "Privacidad y seguridad",
-    "Data collection consent" : "Consentimiento de recolección de datos",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
-    "Trusted senders" : "Remitentes de confianza",
-    "Internal addresses" : "Direcciones internas",
+    "Security" : "Seguridad",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Resalta direcciones de correo electrónico externas al activar esta característica, administra tus direcciones internas y dominios para asegurar que los contactos reconocidos permanezcan sin resaltar.",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Administrar certificados S/MIME",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Características de asistencia",
     "About" : "Acerca",
@@ -257,6 +248,7 @@ OC.L10N.register(
     "Create task" : "Crear tarea",
     "Download message" : "Descargar mensaje",
     "Load more" : "Cargar más",
+    "Mark as important" : "Marcar como importante",
     "Report this bug" : "Reportar este bug",
     "Event created" : "Evento creado",
     "Could not create event" : "No se pudo crear el evento",
@@ -401,7 +393,19 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
+    "Search in the body of messages in priority Inbox" : "Busca en el cuerpo de los mensajes de la bandeja de entrada prioritaria",
     "Put my text to the bottom of a reply instead of on top of it." : "Pon el texto al fondo de una respuesta, en lugar de arriba.",
-    "Vertical split" : "División vertical"
+    "Use internal addresses" : "Usar direcciones internas",
+    "Accounts" : "Cuentas",
+    "Newest" : "Más recientes",
+    "Oldest" : "Más antiguo",
+    "Reply text position" : "Posisión de respuesta del texto",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Register as application for mail links" : "Registrar como aplicación para enlaces de correo electrónico",
+    "Data collection consent" : "Consentimiento de recolección de datos",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permitir que la aplicación recopile datos sobre tus interacciones. Con base en estos datos, la aplicación se adaptará a tus preferencias. Los datos se almacenarán solo localmente.",
+    "Trusted senders" : "Remitentes de confianza",
+    "Internal addresses" : "Direcciones internas",
+    "Manage S/MIME certificates" : "Administrar certificados S/MIME"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
