@@ -28,11 +28,12 @@ OC.L10N.register(
     "Signature" : "Firma",
     "Go back" : "Regresar",
     "Cancel" : "Cancelar",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
+    "Add mail account" : "Agregar cuenta de correo",
+    "Newest first" : "Más reciente primero",
+    "Oldest first" : "Más antiguo primero",
     "Register" : "Registrar",
+    "Security" : "Seguridad",
     "About" : "Acerca de",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Compose new message" : "Escribir mensaje nuevo",
@@ -45,6 +46,7 @@ OC.L10N.register(
     "Search" : "Buscar",
     "Send" : "Enviar",
     "Refresh" : "Actualizar",
+    "Ok" : "Ok",
     "Select account" : "Selecciona la cuenta",
     "Subject" : "Asunto",
     "Upload attachment" : "Cargar adjunto",
@@ -59,6 +61,7 @@ OC.L10N.register(
     "More actions" : "Más acciones",
     "Back" : "Atrás",
     "All day" : "Todo el día",
+    "Attendees" : "Asistentes",
     "Description" : "Descripción",
     "Create" : "Crear",
     "Select" : "Seleccionar",
@@ -67,6 +70,7 @@ OC.L10N.register(
     "Decline" : "Declinar",
     "Remove" : "Eliminar",
     "email" : "correo electrónico",
+    "Today" : "Hoy",
     "Other" : "Otro",
     "Forward" : "Adelante",
     "Translate" : "Traducir",
@@ -79,9 +83,10 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger tu privacidad. ",
     "Move" : "Mover",
     "Remove account" : "Eliminar cuenta",
-    "Quota" : "Cuota",
+    "Folder name" : "Nombre de la carpeta",
     "Saving" : "Guardando",
     "Show all folders" : "Mostrar todas las carpetas",
+    "Collapse folders" : "Compactar carpetas",
     "Mark all as read" : "Marcar todos como leídos",
     "Rename" : "Renombrar",
     "Clear cache" : "Borrar el caché",
@@ -98,8 +103,12 @@ OC.L10N.register(
     "Custom" : "Personalizado",
     "Add tag" : "Agregar etiqueta",
     "Recipient" : "Destinatario",
+    "Help" : "Ayuda",
     "matches" : "coincide",
+    "Actions" : "Acciones",
     "Priority" : "Prioridad",
+    "delete" : "borrar",
+    "Edit" : "Editar",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
@@ -109,6 +118,9 @@ OC.L10N.register(
     "Valid until" : "Válido hasta",
     "Certificate" : "Certificado",
     "Submit" : "Enviar",
+    "Group" : "Grupo",
+    "Shared" : "Compartido",
+    "Shares" : "Elementos compartido",
     "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
@@ -129,6 +141,7 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "Continue to %s" : "Continuar a %s",
-    "Actions" : "Acciones"
+    "Accounts" : "Accounts",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
