@@ -113,48 +113,38 @@ OC.L10N.register(
     "Add alias" : "Lisa alias",
     "Create alias" : "Loo alias",
     "Cancel" : "Katkesta",
-    "Search in the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
     "Activate" : "Lülita sisse",
-    "Mark as important" : "Märgi oluliseks",
     "Remind about messages that require a reply but received none" : "Tuleta mulle meelde kirju, mis eeldavad vastust, kui pole seda veel saanud",
-    "Use internal addresses" : "Kasuta sisemisi aadresse",
     "Could not update preference" : "Eelistust polnud võimalik muuta",
     "Mail settings" : "E-kirjade seadistused",
-    "Accounts" : "Kasutajakontod",
+    "General" : "Üldine",
     "Add mail account" : "Lisa e-posti  konto",
     "Settings for:" : "Seadistused:",
-    "General" : "Üldine",
+    "Appearance" : "Välimus",
     "Layout" : "Välimus",
     "List" : "Nimekiri",
+    "Vertical split" : "Püstjoones jagamine",
     "Horizontal split" : "Rõhtjoones jagamine",
     "Sorting" : "Järjestus",
-    "Newest" : "Uusim",
-    "Oldest" : "Vanim",
+    "Newest first" : "Uuemad eespool",
+    "Oldest first" : "Vanemad eespool",
+    "Message view mode" : "Kirjade vaate liik",
     "Show all messages in thread" : "Näita kõiki kirju jutulõngas",
-    "Show only the selected message" : "Näita vaid valitud kirja",
-    "Reply text position" : "Vastuse teksti asukoht",
+    "Top" : "Üleval",
+    "Bottom" : "All",
     "Search in body" : "Otsi kirja sisust",
     "Gravatar settings" : "Gravatari seadistused",
-    "Use Gravatar and favicon avatars" : "Kasuta Gravatari ja favikonide tunnuspilte",
     "Mailto" : "Mailto",
-    "Register as application for mail links" : "Registreeri mailto: linke avava rakendusena",
     "Register" : "Registreeru",
     "Text blocks" : "Tekstiplokid",
-    "Create a new text block" : "Koosta uus tekstiplokk",
+    "New text block" : "Uus tekstiplokk",
     "Shared with me" : "Jagatud minuga",
     "Privacy and security" : "Privaatsus ja turvalisus",
-    "Data collection consent" : "Nõusolek andmete kogumiseks",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Luba rakendusel koguda andmeid sinu kasutusharjumuste kohta. Nende andmete alusel rakendus kohendab oma seadistusi. Kogutud andmed on säilitatud vaid kohalikus serveris.",
-    "Trusted senders" : "Usaldatud saatjad",
-    "Internal addresses" : "Sisemised aadressid",
+    "Security" : "Turvalisus",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Selle valikuga tõstetakse välised e-posti aadressid esile, hallatakse sinu jaoks serveri sisemisi aadresse ja domeene. Nii tagatakse, et sinu poolt kinnitatud kontaktid jäävad esiletõstmata.",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Halda S/MIME sertifikaate",
     "Mailvelope" : "Mailvelope",
-    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope on brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
     "Mailvelope is enabled for the current domain." : "Mailvelope on selle domeeni puhul kasutusel.",
-    "Step 1: Install Mailvelope browser extension" : "1. samm: Paigalda Mailvelope'i brauserilaiendus",
-    "Step 2: Enable Mailvelope for the current domain" : "2. samm: Võta Mailvelope selle domeeni puhul kasutusele",
     "Assistance features" : "Abilise funktsionaalsused",
     "About" : "Rakenduse teave",
     "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Selles rakenduses sisaldub avatud lähtekoodiga CKEditor, mis on kasutusel kirjade koostamiseks. Autoriõigused: © CKEditori kaasautorid. Litsentseeritud GPLv2 alusel.",
@@ -169,7 +159,6 @@ OC.L10N.register(
     "Search" : "Otsi",
     "Send" : "Saada",
     "Refresh" : "Värskenda",
-    "New text block" : "Uus tekstiplokk",
     "Title of the text block" : "Tekstiploki pealkiri",
     "Content of the text block" : "Tekstiploki sisu",
     "Ok" : "Sobib",
@@ -309,6 +298,7 @@ OC.L10N.register(
     "Mark as unread" : "Märgi mitteloetuks",
     "Mark as read" : "Märgi loetuks",
     "Mark as unimportant" : "Märgi mitteoluliseks",
+    "Mark as important" : "Märgi oluliseks",
     "Report this bug" : "Teata sellest veast",
     "Event created" : "Sündmus on loodud",
     "Could not create event" : "Sündmuse loomine ei õnnestunud",
@@ -704,6 +694,7 @@ OC.L10N.register(
     "User Interface Preference Defaults" : "Kasutusliidese eelistuste vaikimisi väärtused",
     "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "Need on kasutajaliidese eelseadistused, mida iga kasutaja saab oma seadistustest muuta",
     "Message View Mode" : "Kirjade vaate liik",
+    "Show only the selected message" : "Näita vaid valitud kirja",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Algne kiri lisatakse manusena „message/rfc822“ tüüpi failina.",
     "\"Mark as Spam\" Email Address" : "„Märgitud rämpspostiks“ e-posti aadressid",
     "\"Mark Not Junk\" Email Address" : "„Pole rämpspost“ e-posti aadressid",
@@ -742,6 +733,8 @@ OC.L10N.register(
     "LDAP attribute for aliases" : "LDAP-i omadused aliaste jaoks",
     "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Mitmeväärtuseline e-posti aliaste eelkoostamise lahendus. Iga väärtuse kohta luuakse alias. Nexctcloudis leiduvate aliaste puhul, millel pole LDAP-i serveris vastet, kustutakse e-posti teenusest.",
     "Save Config" : "Salvesta seadistus",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% ja %EMAIL% asendatakse kasutajatunnuse (UID) ja e-posti aadressiga",
+    "With the settings above, the app will create account settings in the following way:" : "Ülalmääratud seadistuste alusel loob rakendus kasutajakonto seadistused alljärgneval viisil:",
     "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Lisatud PKCS #12 sertifikaadis peab olema vähemalt üks sertifikaat ning ainult üks privaatvõti.",
     "Failed to import the certificate. Please check the password." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, kas salasõna on õige.",
     "Certificate imported successfully" : "Sertifikaadi importimine õnnestus",
@@ -821,8 +814,23 @@ OC.L10N.register(
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
     "Continue to %s" : "Jätka siia: %s",
+    "Search in the body of messages in priority Inbox" : "Otsi esmase postkasti kirjade sisust",
     "Put my text to the bottom of a reply instead of on top of it." : "Sisesta minu tekst vastuse alla, mitte tema kohale",
-    "Vertical split" : "Püstjoones jagamine",
-    "Older" : "Vanemad"
+    "Use internal addresses" : "Kasuta sisemisi aadresse",
+    "Accounts" : "Kasutajakontod",
+    "Newest" : "Uusim",
+    "Oldest" : "Vanim",
+    "Reply text position" : "Vastuse teksti asukoht",
+    "Use Gravatar and favicon avatars" : "Kasuta Gravatari ja favikonide tunnuspilte",
+    "Register as application for mail links" : "Registreeri mailto: linke avava rakendusena",
+    "Create a new text block" : "Koosta uus tekstiplokk",
+    "Data collection consent" : "Nõusolek andmete kogumiseks",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Luba rakendusel koguda andmeid sinu kasutusharjumuste kohta. Nende andmete alusel rakendus kohendab oma seadistusi. Kogutud andmed on säilitatud vaid kohalikus serveris.",
+    "Trusted senders" : "Usaldatud saatjad",
+    "Internal addresses" : "Sisemised aadressid",
+    "Manage S/MIME certificates" : "Halda S/MIME sertifikaate",
+    "Mailvelope is a browser extension that enables easy OpenPGP encryption and decryption for emails." : "Mailvelope on brauseri lisamoodul, mis võimaldab mugavalt kasutada OpenPGP-põhist e-kirjade krüptimist ja dekrüptimist.",
+    "Step 1: Install Mailvelope browser extension" : "1. samm: Paigalda Mailvelope'i brauserilaiendus",
+    "Step 2: Enable Mailvelope for the current domain" : "2. samm: Võta Mailvelope selle domeeni puhul kasutusele"
 },
 "nplurals=2; plural=(n != 1);");
