@@ -108,39 +108,31 @@ OC.L10N.register(
     "Add alias" : "Gehitu aliasa",
     "Create alias" : "Sortu aliasa",
     "Cancel" : "Utzi",
-    "Search in the body of messages in priority Inbox" : "Bilatu sarrera-ontziko mezuetan",
     "Activate" : "Aktibatu",
-    "Mark as important" : "Markatu garrantzizko gisa",
     "Remind about messages that require a reply but received none" : "Oroitarazi erantzun bat behar zuten baina jaso ez zuten mezuak",
-    "Use internal addresses" : "Erabili barneko helbideak",
     "Could not update preference" : "Ezin izan da hobespena eguneratu",
     "Mail settings" : "Posta ezarpenak",
-    "Accounts" : "Kontuak",
+    "General" : "Orokorra",
     "Add mail account" : "Gehitu posta-kontua",
     "Settings for:" : "Ezarpenak honentzat:",
-    "General" : "Orokorra",
+    "Appearance" : "Itxura",
     "Layout" : "Diseinua",
     "List" : "Zerrenda",
+    "Vertical split" : "Banaketa bertikala",
     "Horizontal split" : "Banaketa horizontala",
     "Sorting" : "Antolaketa",
-    "Newest" : "Berrienak",
-    "Oldest" : "Zaharrenak",
-    "Reply text position" : "Erantzun testuaren posizioa",
+    "Newest first" : "Berrienak lehenengo ",
+    "Oldest first" : "Zaharrenak lehenengo",
     "Search in body" : "Bilatu testuan",
     "Gravatar settings" : "Gravatar ezarpenak",
-    "Use Gravatar and favicon avatars" : "Erabili Gravatar eta favicon avatarrak",
     "Mailto" : "Mailto",
-    "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
     "Register" : "Erregistratu",
     "Shared with me" : "Nirekin partekatuta",
     "Privacy and security" : "Pribatutasuna eta segurtasuna",
-    "Data collection consent" : "Datuak biltzeko baimena",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
-    "Trusted senders" : "Bidaltzaile fidagarriak",
-    "Internal addresses" : "Barneko helbideak",
+    "Security" : "Segurtasuna",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Nabarmendu kanpoko helbide elektronikoak ezaugarri hau gaituz, kudeatu barneko helbideak eta domeinuak kontaktu ezagunak markatu gabe geratuko direla bermatzeko.",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak",
+    "Manage certificates" : "Kudeatu ziurtagiriak",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Laguntzailearen aukerak",
     "About" : "Honi buruz",
@@ -280,6 +272,7 @@ OC.L10N.register(
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Birbidali {zenbakia} eranskin bezala","Birbidali {zenbakia} eranskin bezala"],
     "Mark as unread" : "Markatu ez irakurritako gisa",
     "Mark as read" : "Markatu irakurritako gisa",
+    "Mark as important" : "Markatu garrantzizko gisa",
     "Report this bug" : "Eman errore honen berri",
     "Event created" : "Sortu da gertaera",
     "Could not create event" : "Ezin izan da gertaera sortu",
@@ -738,7 +731,19 @@ OC.L10N.register(
     "The link leads to %s" : "Estekak hona bideratzen du: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Orrialde hori bisitatu nahi ez baduzu, itzul dezakezu <a href=\"%s\">Mail </a>-ra.",
     "Continue to %s" : "Jarraitu hona: %s",
+    "Search in the body of messages in priority Inbox" : "Bilatu sarrera-ontziko mezuetan",
     "Put my text to the bottom of a reply instead of on top of it." : "Jarri nire testua erantzunaren behealdean, goian jarri beharrean.",
-    "Vertical split" : "Banaketa bertikala"
+    "Use internal addresses" : "Erabili barneko helbideak",
+    "Accounts" : "Kontuak",
+    "Newest" : "Berrienak",
+    "Oldest" : "Zaharrenak",
+    "Reply text position" : "Erantzun testuaren posizioa",
+    "Use Gravatar and favicon avatars" : "Erabili Gravatar eta favicon avatarrak",
+    "Register as application for mail links" : "Erregistratu posta-estekentzako aplikazio bezala",
+    "Data collection consent" : "Datuak biltzeko baimena",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Baimena eman aplikazioari zure interakzioei buruzko datuak biltzeko. Datu horietan oinarrituta, aplikazioa zure hobespenetara egokituko da. Datuak lokalki bakarrik gordeko dira.",
+    "Trusted senders" : "Bidaltzaile fidagarriak",
+    "Internal addresses" : "Barneko helbideak",
+    "Manage S/MIME certificates" : "Kudeatu S/MIME ziurtagiriak"
 },
 "nplurals=2; plural=(n != 1);");
