@@ -96,21 +96,17 @@ OC.L10N.register(
     "Cancel" : "لغو",
     "Could not update preference" : "Could not update preference",
     "Mail settings" : "Mail settings",
-    "Accounts" : "حساب‌ها",
-    "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
     "General" : "عمومی",
+    "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
+    "Appearance" : "ظاهر",
     "Layout" : "چیدمان",
     "List" : "فهرست",
     "Sorting" : "مرتب سازی",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
-    "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
+    "Newest first" : "نخست جدیدترین",
+    "Oldest first" : "نخست قدیمی‌ترین",
     "Register" : "ثبت‌نام",
     "Shared with me" : "Shared with me",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
-    "Trusted senders" : "Trusted senders",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates",
+    "Security" : "امنیتی",
     "About" : "About",
     "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
     "Compose new message" : "نوشتن پیام جدید",
@@ -608,6 +604,14 @@ OC.L10N.register(
     "The link leads to %s" : "پیوند منجر به%s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it."
+    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
+    "Accounts" : "حساب‌ها",
+    "Newest" : "Newest",
+    "Oldest" : "Oldest",
+    "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
+    "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
+    "Trusted senders" : "Trusted senders",
+    "Manage S/MIME certificates" : "Manage S/MIME certificates"
 },
 "nplurals=2; plural=(n > 1);");
