@@ -87,33 +87,27 @@ OC.L10N.register(
     "Cancel" : "Peruuta",
     "Could not update preference" : "Asetuksia ei voitu päivittää",
     "Mail settings" : "Sähköpostin asetukset",
-    "Accounts" : "Tilit",
-    "Add mail account" : "Lisää sähköpostitili",
     "General" : "Yleiset",
+    "Add mail account" : "Lisää sähköpostitili",
+    "Appearance" : "Ulkoasu",
     "Layout" : "Asettelu",
     "List" : "Lista",
+    "Vertical split" : "Pystysuunnan jako",
     "Horizontal split" : "Vaakasuunnan jako",
     "Sorting" : "Lajittelu",
-    "Newest" : "Uusimmat",
-    "Oldest" : "Vanhimmat",
+    "Newest first" : "Uusin ensin",
+    "Oldest first" : "Vanhin ensin",
     "Show all messages in thread" : "Näytä kaikki viestit ketjussa",
-    "Show only the selected message" : "Näytä vain valittu viesti",
     "Search in body" : "Etsi sisällöstä",
     "Gravatar settings" : "Gravatar-asetukset",
-    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
-    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
     "Register" : "Rekisteröidy",
     "Text blocks" : "Tekstilohkot",
-    "Create a new text block" : "Luo uusi tekstilohko",
+    "New text block" : "Uusi tekstilohko",
     "Shared with me" : "Jaettu kanssasi",
     "Privacy and security" : "Yksityisyys ja turvallisuus",
-    "Data collection consent" : "Datakeruun suostumus",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
-    "Trusted senders" : "Luotetut lähettäjät",
+    "Security" : "Tietoturva",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
-    "Step 1: Install Mailvelope browser extension" : "Vaihe 1: Asenna Mailvelope-selainlaajennus",
-    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle",
+    "Manage certificates" : "Hallitse varmenteita",
     "About" : "Tietoja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Compose new message" : "Uusi viesti",
@@ -126,7 +120,6 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
-    "New text block" : "Uusi tekstilohko",
     "Title of the text block" : "Tekstilohkon otsikko",
     "Content of the text block" : "Tekstilohkon sisältö",
     "Ok" : "Ok",
@@ -519,6 +512,7 @@ OC.L10N.register(
     "Gmail integration" : "Gmail-integraatio",
     "Microsoft integration" : "Microsoft-integraatio",
     "Message View Mode" : "Viestin näyttötapa",
+    "Show only the selected message" : "Näytä vain valittu viesti",
     "Anti Spam" : "Roskapostin esto",
     "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
     "Reset" : "Palauta",
@@ -608,7 +602,17 @@ OC.L10N.register(
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
     "Continue to %s" : "Jatka sivulle %s",
     "Put my text to the bottom of a reply instead of on top of it." : "Aseta tekstini vastauksen alaosaan yläosan sijaan",
-    "Vertical split" : "Pystysuunnan jako",
-    "Older" : "Vanhempi"
+    "Accounts" : "Tilit",
+    "Newest" : "Uusimmat",
+    "Oldest" : "Vanhimmat",
+    "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
+    "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
+    "Create a new text block" : "Luo uusi tekstilohko",
+    "Data collection consent" : "Datakeruun suostumus",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
+    "Trusted senders" : "Luotetut lähettäjät",
+    "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
+    "Step 1: Install Mailvelope browser extension" : "Vaihe 1: Asenna Mailvelope-selainlaajennus",
+    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle"
 },
 "nplurals=2; plural=(n != 1);");
