@@ -54,15 +54,15 @@ OC.L10N.register(
     "Email address" : "כתובת דוא״ל",
     "Add alias" : "הוספת כינוי",
     "Cancel" : "ביטול",
-    "Accounts" : "Accounts",
-    "Add mail account" : "הוספת חשבון דוא״ל",
     "General" : "כללי",
+    "Add mail account" : "הוספת חשבון דוא״ל",
+    "Appearance" : "מראה",
     "Sorting" : "מיון",
-    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
-    "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
+    "Newest first" : "החדש ביותר ראשון",
+    "Oldest first" : "הישן ביותר ראשון",
     "Register" : "רישום",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
-    "Trusted senders" : "שולחים מהימנים",
+    "Security" : "אבטחה",
+    "Manage certificates" : "ניהול אישורים",
     "About" : "אודות",
     "Keyboard shortcuts" : "קיצורי מקלדת",
     "Compose new message" : "כתיבת הודעה חדשה",
@@ -279,6 +279,11 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
     "Redirect" : "הפנייה",
     "The link leads to %s" : "הקישור מוביל אל %s",
-    "Continue to %s" : "ממשיך אל %s"
+    "Continue to %s" : "ממשיך אל %s",
+    "Accounts" : "Accounts",
+    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
+    "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
+    "Trusted senders" : "שולחים מהימנים"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
