@@ -59,17 +59,17 @@ OC.L10N.register(
     "Create alias" : "Stvori pseudonim",
     "Cancel" : "Odustani",
     "Could not update preference" : "Ažuriranje postavki nije uspjelo",
-    "Accounts" : "Korisnićki računi",
-    "Add mail account" : "Dodaj račun e-pošte",
     "General" : "Općenito",
+    "Add mail account" : "Dodaj račun e-pošte",
+    "Appearance" : "Izgled",
     "List" : "Popis",
     "Sorting" : "Razvrstavanje",
-    "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
-    "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
+    "Newest first" : "Najnoviji prvi",
+    "Oldest first" : "Najstariji prvi",
     "Register" : "Registriraj se",
     "Shared with me" : "Dijeljeno sa mnom",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
-    "Trusted senders" : "Pouzdani pošiljatelji",
+    "Security" : "Sigurnost",
+    "Manage certificates" : "Upravljanje vjerodajnicama",
     "About" : "Informacije",
     "Keyboard shortcuts" : "Tipkovni prečaci",
     "Compose new message" : "Sastavi novu poruku",
@@ -386,6 +386,11 @@ OC.L10N.register(
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
     "Continue to %s" : "Idi do %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh."
+    "Put my text to the bottom of a reply instead of on top of it." : "Stavite tekst na dno odgovora umjesto na vrh.",
+    "Accounts" : "Korisnićki računi",
+    "Use Gravatar and favicon avatars" : "Upotrijebi avatare Gravatar i Favicon",
+    "Register as application for mail links" : "Registriraj kao aplikaciju za poveznice e-pošte",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Dopustite aplikaciji da prikuplja podatke o vašim interakcijama. Aplikacija će se prilagoditi vašim željama na temelju tih podataka. Podaci će biti pohranjeni samo lokalno.",
+    "Trusted senders" : "Pouzdani pošiljatelji"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
