@@ -97,20 +97,17 @@ OC.L10N.register(
     "Cancel" : "Mégse",
     "Could not update preference" : "Nem sikerült frissíteni a beállítást",
     "Mail settings" : "Levelezési beállítások",
-    "Accounts" : "Fiókok",
-    "Add mail account" : "E-mail-fiók hozzáadása",
     "General" : "Általános",
+    "Add mail account" : "E-mail-fiók hozzáadása",
+    "Appearance" : "Megjelenés",
     "List" : "Lista",
     "Sorting" : "Rendezés",
-    "Newest" : "Legújabb",
-    "Oldest" : "Legrégebbi",
-    "Use Gravatar and favicon avatars" : "Gravatar és favicon profilképek használata",
-    "Register as application for mail links" : "Alkalmazás beállítása a levélhivatkozásokhoz",
+    "Newest first" : "Legújabb elöl",
+    "Oldest first" : "Régebbiek elöl",
     "Register" : "Regisztráció",
     "Shared with me" : "Megosztva velem",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Engedélyezés az alkalmazásnak, hogy az adatokat gyűjtsön az interakcióiról. Az adatok alapján az alkalmazás alkalmazkodni fog a használati szokásaihoz. Az adatok helyben lesznek tárolva.",
-    "Trusted senders" : "Megbízható küldők",
-    "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése",
+    "Security" : "Biztonság",
+    "Manage certificates" : "Tanúsítványok kezelése",
     "About" : "Névjegy",
     "Keyboard shortcuts" : "Gyorsbillentyűk",
     "Compose new message" : "Új üzenet írása",
@@ -642,6 +639,14 @@ OC.L10N.register(
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
     "Continue to %s" : "Folytatás ide: %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "A szöveg a válasz aljára helyezése a teteje helyett."
+    "Put my text to the bottom of a reply instead of on top of it." : "A szöveg a válasz aljára helyezése a teteje helyett.",
+    "Accounts" : "Fiókok",
+    "Newest" : "Legújabb",
+    "Oldest" : "Legrégebbi",
+    "Use Gravatar and favicon avatars" : "Gravatar és favicon profilképek használata",
+    "Register as application for mail links" : "Alkalmazás beállítása a levélhivatkozásokhoz",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Engedélyezés az alkalmazásnak, hogy az adatokat gyűjtsön az interakcióiról. Az adatok alapján az alkalmazás alkalmazkodni fog a használati szokásaihoz. Az adatok helyben lesznek tárolva.",
+    "Trusted senders" : "Megbízható küldők",
+    "Manage S/MIME certificates" : "S/MIME tanúsítványok kezelése"
 },
 "nplurals=2; plural=(n != 1);");
