@@ -83,23 +83,20 @@ OC.L10N.register(
     "Activate" : "Attiva",
     "Could not update preference" : "Impossibile aggiornare la preferenza",
     "Mail settings" : "Impostazioni Posta",
-    "Accounts" : "Account",
-    "Add mail account" : "Aggiungi account di posta",
     "General" : "Generale",
+    "Add mail account" : "Aggiungi account di posta",
+    "Appearance" : "Aspetto",
     "Layout" : "Disposizione",
     "List" : "Elenco",
     "Sorting" : "Ordina",
-    "Newest" : "Più recente",
-    "Oldest" : "Il più datato",
+    "Newest first" : "Prima i più recenti",
+    "Oldest first" : "Prima i più datati",
     "Gravatar settings" : "Impostazioni Gravatar",
-    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
-    "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
     "Register" : "Registra",
     "Shared with me" : "Condivisi con me",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
-    "Trusted senders" : "Mittenti affidabili",
+    "Security" : "Sicurezza",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Gestisci i certificati S/MIME",
+    "Manage certificates" : "Gestisci certificati",
     "Mailvelope" : "Mailvelope",
     "About" : "Informazioni",
     "Keyboard shortcuts" : "Scorciatoie da tastiera",
@@ -568,6 +565,14 @@ OC.L10N.register(
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
     "Continue to %s" : "Continua su %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Inserisci il mio testo in fondo alla risposta invece che sopra."
+    "Put my text to the bottom of a reply instead of on top of it." : "Inserisci il mio testo in fondo alla risposta invece che sopra.",
+    "Accounts" : "Account",
+    "Newest" : "Più recente",
+    "Oldest" : "Il più datato",
+    "Use Gravatar and favicon avatars" : "Utilizza Gravatar e avatar favicon",
+    "Register as application for mail links" : "Registra come applicazione per i collegamenti di posta",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Consenti all'applicazione di raccogliere dati sulle tue interazioni. Sulla base di questi dati, l'applicazione si adatterà alle tue preferenze. I dati saranno archiviati solo localmente.",
+    "Trusted senders" : "Mittenti affidabili",
+    "Manage S/MIME certificates" : "Gestisci i certificati S/MIME"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
