@@ -94,29 +94,21 @@ OC.L10N.register(
     "Add alias" : "Add alias",
     "Create alias" : "Create alias",
     "Cancel" : "Cancel",
-    "Search in the body of messages in priority Inbox" : "Search in the body of messages in priority Inbox",
     "Activate" : "Activate",
     "Could not update preference" : "Could not update preference",
     "Mail settings" : "Mail settings",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Add mail account",
     "General" : "General",
+    "Add mail account" : "Add mail account",
     "List" : "List",
     "Sorting" : "Sorting",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Reply text position" : "Reply text position",
+    "Newest first" : "Newest first",
+    "Oldest first" : "Oldest first",
     "Gravatar settings" : "Gravatar settings",
-    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
     "Mailto" : "Mailto",
-    "Register as application for mail links" : "Register as application for mail links",
     "Register" : "Register",
     "Shared with me" : "Shared with me",
-    "Data collection consent" : "Data collection consent",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
-    "Trusted senders" : "Trusted senders",
+    "Security" : "Security",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Manage S/MIME certificates",
     "Mailvelope" : "Mailvelope",
     "About" : "About",
     "Keyboard shortcuts" : "Keyboard shortcuts",
@@ -640,6 +632,17 @@ OC.L10N.register(
     "The link leads to %s" : "The link leads to %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continue to %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it."
+    "Search in the body of messages in priority Inbox" : "Search in the body of messages in priority Inbox",
+    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
+    "Accounts" : "Accounts",
+    "Newest" : "Newest",
+    "Oldest" : "Oldest",
+    "Reply text position" : "Reply text position",
+    "Use Gravatar and favicon avatars" : "Use Gravatar and favicon avatars",
+    "Register as application for mail links" : "Register as application for mail links",
+    "Data collection consent" : "Data collection consent",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
+    "Trusted senders" : "Trusted senders",
+    "Manage S/MIME certificates" : "Manage S/MIME certificates"
 },
 "nplurals=2; plural=(n!=1);");
