@@ -93,34 +93,27 @@ OC.L10N.register(
     "Add alias" : "별칭 추가",
     "Create alias" : "별칭 만들기",
     "Cancel" : "취소",
-    "Search in the body of messages in priority Inbox" : "우선 편지함에서 메시지 본문 검색",
     "Activate" : "활성화",
     "Could not update preference" : "환경설정을 업데이트할 수 없습니다.",
     "Mail settings" : "메일 설정",
-    "Accounts" : "계정",
-    "Add mail account" : "메일 계정 추가",
     "General" : "일반",
+    "Add mail account" : "메일 계정 추가",
+    "Appearance" : "외형",
     "Layout" : "레이아웃",
     "List" : "목록",
+    "Vertical split" : "수직 분할",
     "Horizontal split" : "수평 분할",
     "Sorting" : "정렬",
-    "Newest" : "최신순",
-    "Oldest" : "과거순",
-    "Reply text position" : "답장 문구 위치",
+    "Newest first" : "최신순",
+    "Oldest first" : "오래된순",
     "Search in body" : "본문 검색",
     "Gravatar settings" : "Gravatar 설정",
-    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
-    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
     "Register" : "등록",
     "Text blocks" : "텍스트 블록",
-    "Create a new text block" : "새로운 텍스트 블록 생성",
+    "New text block" : "새로운 텍스트 블록",
     "Privacy and security" : "개인정보 및 보안",
-    "Data collection consent" : "데이터 수집 동의",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
-    "Trusted senders" : "신뢰할 수 있는 발신자",
-    "Internal addresses" : "내부 주소",
+    "Security" : "보안",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "S/MIME 인증서 관리",
     "Mailvelope" : "Mailvelope",
     "Keyboard shortcuts" : "키보드 단축키",
     "Compose new message" : "새 메시지 작성",
@@ -133,7 +126,6 @@ OC.L10N.register(
     "Search" : "검색",
     "Send" : "보내기",
     "Refresh" : "새로 고침",
-    "New text block" : "새로운 텍스트 블록",
     "Title of the text block" : "텍스트 블록의 제목",
     "Content of the text block" : "텍스트 블록의 내용",
     "Ok" : "확인",
@@ -657,7 +649,19 @@ OC.L10N.register(
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동",
+    "Search in the body of messages in priority Inbox" : "우선 편지함에서 메시지 본문 검색",
     "Put my text to the bottom of a reply instead of on top of it." : "내 텍스트를 답장 위가 아니라 답장 맨 아래에 놓기",
-    "Vertical split" : "수직 분할"
+    "Accounts" : "계정",
+    "Newest" : "최신순",
+    "Oldest" : "과거순",
+    "Reply text position" : "답장 문구 위치",
+    "Use Gravatar and favicon avatars" : "Gravatar 및 파비콘 아바타 사용",
+    "Register as application for mail links" : "메일 링크를 어플리케이션으로 등록",
+    "Create a new text block" : "새로운 텍스트 블록 생성",
+    "Data collection consent" : "데이터 수집 동의",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "앱이 상호 작용에 대한 데이터를 수집하도록 허용합니다. 이 데이터를 기반으로 앱이 사용자의 기본 설정에 맞게 조정됩니다. 데이터는 로컬에만 저장됩니다.",
+    "Trusted senders" : "신뢰할 수 있는 발신자",
+    "Internal addresses" : "내부 주소",
+    "Manage S/MIME certificates" : "S/MIME 인증서 관리"
 },
 "nplurals=1; plural=0;");
