@@ -74,26 +74,21 @@ OC.L10N.register(
     "Email address" : "El. pašto adresas",
     "Add alias" : "Pridėti alternatyvų vardą",
     "Cancel" : "Atsisakyti",
-    "Use internal addresses" : "Naudoti vidinius adresus",
     "Could not update preference" : "Nepavyko atnaujinti nuostatos",
     "Mail settings" : "Pašto nustatymai",
-    "Accounts" : "Paskyros",
-    "Add mail account" : "Pridėti pašto paskyrą",
     "General" : "Bendra",
+    "Add mail account" : "Pridėti pašto paskyrą",
+    "Appearance" : "Išvaizda",
     "Layout" : "Išdėstymas",
     "List" : "Sąrašas",
     "Sorting" : "Rikiavimas",
-    "Newest" : "Naujausios",
-    "Oldest" : "Seniausios",
-    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
-    "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
+    "Newest first" : "Naujausi pirma",
+    "Oldest first" : "Seniausi pirma",
     "Register" : "Registruotis",
     "Privacy and security" : "Privatumas ir saugumas",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
-    "Trusted senders" : "Patikimi siuntėjai",
-    "Internal addresses" : "Vidiniai adresai",
+    "Security" : "Saugumas",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus",
+    "Manage certificates" : "Tvarkyti liudijimus",
     "About" : "Apie",
     "Keyboard shortcuts" : "Spartieji klavišai",
     "Compose new message" : "Rašyti naują laišką",
@@ -449,6 +444,16 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
-    "Continue to %s" : "Tęsti į %s"
+    "Continue to %s" : "Tęsti į %s",
+    "Use internal addresses" : "Naudoti vidinius adresus",
+    "Accounts" : "Paskyros",
+    "Newest" : "Naujausios",
+    "Oldest" : "Seniausios",
+    "Use Gravatar and favicon avatars" : "Naudoti Gravatar ir svetainių piktogramų avatarus",
+    "Register as application for mail links" : "Registruoti kaip pašto nuorodų programėlę",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Leisti programėlei rinkti duomenis apie jūsų sąveikas. Remiantis šiais duomenimis, programėlė prisitaikys prie jūsų nuostatų. Duomenys bus laikomi tik vietoje.",
+    "Trusted senders" : "Patikimi siuntėjai",
+    "Internal addresses" : "Vidiniai adresai",
+    "Manage S/MIME certificates" : "Tvarkyti S/MIME liudijimus"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
