@@ -47,9 +47,12 @@ OC.L10N.register(
     "Go back" : "Atpakaļ",
     "Email address" : "E-pasta adrese",
     "Cancel" : "Atcelt",
-    "Accounts" : "Konti",
-    "Add mail account" : "Pievienot e-pasta kontu",
     "General" : "Vispārīgi",
+    "Add mail account" : "Pievienot e-pasta kontu",
+    "Appearance" : "Izskats",
+    "Newest first" : "Jaunākie pirms",
+    "Oldest first" : "Vecākie pirms",
+    "Security" : "Drošība",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Archive" : "Arhīvi",
     "Delete" : "Izdzēst",
@@ -180,6 +183,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s"
+    "Continue to %s" : "Turpināt %s",
+    "Accounts" : "Konti"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
