@@ -85,35 +85,26 @@ OC.L10N.register(
     "Add alias" : "Додади псевдоним",
     "Create alias" : "Креирај алијас",
     "Cancel" : "Откажи",
-    "Search in the body of messages in priority Inbox" : "Барај во пораката во приоритетното сандаче",
     "Activate" : "Активирај",
-    "Mark as important" : "Ознали како важна",
-    "Use internal addresses" : "Користи внатрешни адреси",
     "Could not update preference" : "Неможе да се ажурираат параметрите",
     "Mail settings" : "Параметри за е-пошта",
-    "Accounts" : "Сметки",
+    "General" : "Општо",
     "Add mail account" : "Додади е-пошта сметка",
     "Settings for:" : "Параметри за:",
-    "General" : "Општо",
+    "Appearance" : "Изглед",
     "Layout" : "Распоред",
     "List" : "Листа",
+    "Vertical split" : "Вертикална поделба",
     "Horizontal split" : "Хоризонтална поделба",
     "Sorting" : "Сортирање",
-    "Newest" : "Најнови",
-    "Oldest" : "Најстари",
-    "Reply text position" : "Позиција на одговорот",
+    "Newest first" : "Новите прво",
+    "Oldest first" : "Старите прво",
     "Search in body" : "Барај по пораката",
     "Gravatar settings" : "Параметри за Gravatar ",
-    "Use Gravatar and favicon avatars" : "Користете Граватар и Фавикон аватари",
-    "Register as application for mail links" : "Регистрирај како апликација за отварање на е-пошта линкови ",
     "Register" : "Регистрирај се",
     "Privacy and security" : "Приватност и безбедност",
-    "Data collection consent" : "Согласност за собирање податоци",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
-    "Trusted senders" : "Доверливи испраќачи",
-    "Internal addresses" : "Внатрешни адреси",
+    "Security" : "Безбедност",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Означете ги надворешните е-адреси со овозможување на оваа функција, управувајте со вашите внатрешни адреси и домени за да се осигурате дека препознаените контакти остануваат необележани.",
-    "Manage S/MIME certificates" : "Управувај со S/MIME серификатите",
     "About" : "За",
     "This application includes CKEditor, an open-source editor. Copyright © CKEditor contributors. Licensed under GPLv2." : "Оваа апликација го вклучува CKEditor, уредник со отворен код. Copyright © CKEditor contributors. Лиценцирано под GPLv2.",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
@@ -223,6 +214,7 @@ OC.L10N.register(
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Препрати како {number} прилог","Препрати {number} како прилози"],
     "Mark as unread" : "Означи како непрочитано",
     "Mark as read" : "Означи како прочитано",
+    "Mark as important" : "Ознали како важна",
     "Report this bug" : "Пријави грешка",
     "Event created" : "Создаден е настан",
     "Could not create event" : "Неможе да се креира настан",
@@ -485,7 +477,19 @@ OC.L10N.register(
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
     "Continue to %s" : "Продолжи до %s",
+    "Search in the body of messages in priority Inbox" : "Барај во пораката во приоритетното сандаче",
     "Put my text to the bottom of a reply instead of on top of it." : "Стави го мојот текст на дното од одговорот наместо врз него.",
-    "Vertical split" : "Вертикална поделба"
+    "Use internal addresses" : "Користи внатрешни адреси",
+    "Accounts" : "Сметки",
+    "Newest" : "Најнови",
+    "Oldest" : "Најстари",
+    "Reply text position" : "Позиција на одговорот",
+    "Use Gravatar and favicon avatars" : "Користете Граватар и Фавикон аватари",
+    "Register as application for mail links" : "Регистрирај како апликација за отварање на е-пошта линкови ",
+    "Data collection consent" : "Согласност за собирање податоци",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Дозволете апликацијата да собира податоци за вашите интеракции. Врз основа на овие податоци, апликацијата ќе се прилагоди на вашите потреби. Податоците ќе се зачувуваат само локално.",
+    "Trusted senders" : "Доверливи испраќачи",
+    "Internal addresses" : "Внатрешни адреси",
+    "Manage S/MIME certificates" : "Управувај со S/MIME серификатите"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
