@@ -105,37 +105,29 @@ OC.L10N.register(
     "Add alias" : "Legg til alias",
     "Create alias" : "Opprett alias",
     "Cancel" : "Avbryt",
-    "Search in the body of messages in priority Inbox" : "Søke i meldingsteksten i prioritert innboks",
     "Activate" : "Aktiver",
-    "Mark as important" : "Merk som viktig",
     "Remind about messages that require a reply but received none" : "Påminnelse om meldinger som krever svar, men ikke har mottatt noen",
-    "Use internal addresses" : "Bruk interne adresser",
     "Could not update preference" : "Kunne ikke oppdatere preferanse",
     "Mail settings" : "E-post instillinger",
-    "Accounts" : "Kontoer",
-    "Add mail account" : "Legg til e-postkonto",
     "General" : "Generell",
+    "Add mail account" : "Legg til e-postkonto",
+    "Appearance" : "Utseende",
     "Layout" : "Utforming",
     "List" : "Liste",
+    "Vertical split" : "Loddrett deling",
     "Horizontal split" : "Horisontal deling",
     "Sorting" : "Sorter",
-    "Newest" : "Nyeste",
-    "Oldest" : "Eldst",
-    "Reply text position" : "Svartekstposisjon",
+    "Newest first" : "Nyeste først",
+    "Oldest first" : "Eldste først",
     "Search in body" : "Søk i innholdstekst",
     "Gravatar settings" : "Gravatar-innstillinger",
-    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
     "Mailto" : "Mailto",
-    "Register as application for mail links" : "Registrer som applikasjon for e-postlenker",
     "Register" : "Registrer",
     "Privacy and security" : "Personvern og sikkerhet",
-    "Data collection consent" : "Samtykke til innsamling av data",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillat at appen samler inn data om interaksjonene dine. Basert på disse dataene vil appen tilpasse seg dine preferanser. Dataene vil kun bli lagret lokalt.",
-    "Trusted senders" : "Pålitelige avsendere",
-    "Internal addresses" : "Interne adresser",
+    "Security" : "Sikkerhet",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "Fremhev eksterne e-postadresser ved å aktivere denne funksjonen, administrer dine interne adresser og domener for å sikre at gjenkjente kontakter forblir umerket.",
     "S/MIME" : "S/MIME",
-    "Manage S/MIME certificates" : "Administrer S/MIME-sertifikater",
+    "Manage certificates" : "Administrer sertifikat",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "Assistanse funksjoner",
     "About" : "Om",
@@ -275,6 +267,7 @@ OC.L10N.register(
     "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Videresend {number} som vedlegg","Videresend {number} som vedlegg"],
     "Mark as unread" : "Merk som ulest",
     "Mark as read" : "Merk som lest",
+    "Mark as important" : "Merk som viktig",
     "Report this bug" : "Rapporter denne feilen",
     "Event created" : "Hendelse opprettet",
     "Could not create event" : "Kunne ikke opprette hendelsen",
@@ -711,7 +704,19 @@ OC.L10N.register(
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
     "Continue to %s" : "Fortsett til %s",
+    "Search in the body of messages in priority Inbox" : "Søke i meldingsteksten i prioritert innboks",
     "Put my text to the bottom of a reply instead of on top of it." : "Legg teksten min nederst i et svar i stedet for på toppen av det.",
-    "Vertical split" : "Loddrett deling"
+    "Use internal addresses" : "Bruk interne adresser",
+    "Accounts" : "Kontoer",
+    "Newest" : "Nyeste",
+    "Oldest" : "Eldst",
+    "Reply text position" : "Svartekstposisjon",
+    "Use Gravatar and favicon avatars" : "Bruk Gravatar- og favikon-avatarer",
+    "Register as application for mail links" : "Registrer som applikasjon for e-postlenker",
+    "Data collection consent" : "Samtykke til innsamling av data",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Tillat at appen samler inn data om interaksjonene dine. Basert på disse dataene vil appen tilpasse seg dine preferanser. Dataene vil kun bli lagret lokalt.",
+    "Trusted senders" : "Pålitelige avsendere",
+    "Internal addresses" : "Interne adresser",
+    "Manage S/MIME certificates" : "Administrer S/MIME-sertifikater"
 },
 "nplurals=2; plural=(n != 1);");
