@@ -54,17 +54,14 @@ OC.L10N.register(
     "Email address" : "Endereço de email",
     "Add alias" : "Adicionar alcunha",
     "Cancel" : "Cancelar",
-    "Accounts" : "Contas",
-    "Add mail account" : "Adicionar conta de email",
     "General" : "Geral",
+    "Add mail account" : "Adicionar conta de email",
     "List" : "Lista",
-    "Newest" : "Newest",
-    "Oldest" : "Oldest",
-    "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
-    "Register as application for mail links" : "Registar como aplicação para ligações de correio",
+    "Newest first" : "Recentes primeiro",
+    "Oldest first" : "Antigos primeiro",
     "Register" : "Registar",
     "Shared with me" : "Partilhadas comigo",
-    "Trusted senders" : "Remetentes confiáveis",
+    "Security" : "Segurança",
     "About" : "Sobre",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Compose new message" : "Compor nova mensagem",
@@ -246,6 +243,12 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s"
+    "Continue to %s" : "Continuar para %s",
+    "Accounts" : "Contas",
+    "Newest" : "Newest",
+    "Oldest" : "Oldest",
+    "Use Gravatar and favicon avatars" : "Usar Gravatar e favicon avatars",
+    "Register as application for mail links" : "Registar como aplicação para ligações de correio",
+    "Trusted senders" : "Remetentes confiáveis"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
