@@ -89,22 +89,17 @@ OC.L10N.register(
     "Add alias" : "Adaugă alias",
     "Create alias" : "Creează alias",
     "Cancel" : "Anulează",
-    "Search in the body of messages in priority Inbox" : "Caută în conținutul mesajelor din Inboxul prioritar",
     "Could not update preference" : "Preferințele nu au putut fi actualizate",
     "Mail settings" : "Setări Mail",
-    "Accounts" : "Conturi",
-    "Add mail account" : "Adaugă un cont de mail",
     "General" : "General",
+    "Add mail account" : "Adaugă un cont de mail",
+    "Appearance" : "Aspect",
     "List" : "Listă",
-    "Newest" : "Cele mai recente",
-    "Oldest" : "Cele mai vechi",
-    "Use Gravatar and favicon avatars" : "Folosiți avataruri Gravatar și favicon",
-    "Register as application for mail links" : "Înregistrează ca aplicație pentru\nlink-urile de mail",
+    "Newest first" : "Cel mai nou mai întâi",
+    "Oldest first" : "Cel mai vechi mai întâi",
     "Register" : "Înregistrează-te",
     "Shared with me" : "Partajat cu mine",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permiteți aplicației să colecteze date despre interacțiunile dumneavoastră. Aplicația se va adapta preferințelor dumneavoastră în funcție de aceste date. Datele sunt stocate doar local.",
-    "Trusted senders" : "Expeditori de încredere",
-    "Manage S/MIME certificates" : "Administrează certificatele  S/MIME",
+    "Security" : "Securitate",
     "About" : "Despre",
     "Keyboard shortcuts" : "Scurtături din tastatură",
     "Compose new message" : "Compuneți mesaje noi",
@@ -511,6 +506,15 @@ OC.L10N.register(
     "The link leads to %s" : "Link-ul duce la %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Dacă nu doriți să vizitați acea pagină, vă puteți întoarce la <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continuă către %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pune textul la sfârșitul răspunsului în loc de deasupra."
+    "Search in the body of messages in priority Inbox" : "Caută în conținutul mesajelor din Inboxul prioritar",
+    "Put my text to the bottom of a reply instead of on top of it." : "Pune textul la sfârșitul răspunsului în loc de deasupra.",
+    "Accounts" : "Conturi",
+    "Newest" : "Cele mai recente",
+    "Oldest" : "Cele mai vechi",
+    "Use Gravatar and favicon avatars" : "Folosiți avataruri Gravatar și favicon",
+    "Register as application for mail links" : "Înregistrează ca aplicație pentru\nlink-urile de mail",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permiteți aplicației să colecteze date despre interacțiunile dumneavoastră. Aplicația se va adapta preferințelor dumneavoastră în funcție de aceste date. Datele sunt stocate doar local.",
+    "Trusted senders" : "Expeditori de încredere",
+    "Manage S/MIME certificates" : "Administrează certificatele  S/MIME"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
