@@ -55,17 +55,15 @@ OC.L10N.register(
     "Create alias" : "Crea identidade",
     "Cancel" : "Annulla",
     "Could not update preference" : "No at fatu a agiornare sa preferèntzia",
-    "Accounts" : "Accounts",
-    "Add mail account" : "Agiunghe contu de posta",
     "General" : "Generale",
+    "Add mail account" : "Agiunghe contu de posta",
+    "Appearance" : "Aspetu",
     "Sorting" : "Assentende",
-    "Newest" : "Prus nou",
-    "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
-    "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
+    "Newest first" : "In antis is prus reghentes",
+    "Oldest first" : "In antis is prus betzos",
     "Register" : "Registra",
     "Shared with me" : "Cumpartzidos cun megus",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
-    "Trusted senders" : "Imbiantes afidàbiles",
+    "Security" : "Seguresa",
     "About" : "In contu de",
     "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
     "Compose new message" : "Iscrie messàgiu nou",
@@ -356,6 +354,12 @@ OC.L10N.register(
     "Redirect" : "Torra a deretare",
     "The link leads to %s" : "Su ligòngiu deretat a %s",
     "Continue to %s" : "Sighi in %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Pone su testu miu a su fundu de una resposta imbetzes che a pitzus."
+    "Put my text to the bottom of a reply instead of on top of it." : "Pone su testu miu a su fundu de una resposta imbetzes che a pitzus.",
+    "Accounts" : "Accounts",
+    "Newest" : "Prus nou",
+    "Use Gravatar and favicon avatars" : "Imprea Gravatar e avatar favicon",
+    "Register as application for mail links" : "Registra comente aplicatzione pro is ligòngios de posta",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Permite a s'aplicatzione de regòllere datos subra is interatziones tuas. In sa base de custos datos, s'aplicatziones s'at a adatare a is preferèntzias tuas. Is datos ant a èssere archiviados in manera locale isceti. ",
+    "Trusted senders" : "Imbiantes afidàbiles"
 },
 "nplurals=2; plural=(n != 1);");
