@@ -86,22 +86,18 @@ OC.L10N.register(
     "Cancel" : "Prekliči",
     "Could not update preference" : "Lastnosti ni mogoče posodobiti",
     "Mail settings" : "Nastavitve pošte",
-    "Accounts" : "Računi",
-    "Add mail account" : "Dodaj račun elektronske pošte",
     "General" : "Splošno",
+    "Add mail account" : "Dodaj račun elektronske pošte",
+    "Appearance" : "Videz",
     "List" : "Seznam",
     "Sorting" : "Razvrščanje",
-    "Newest" : "Najnovejše",
-    "Oldest" : "Najstarejše",
+    "Newest first" : "najprej najnovejše",
+    "Oldest first" : "najprej najstarejše",
     "Gravatar settings" : "Nastavitve Gravatar",
-    "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
-    "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
     "Register" : "Vpis računa",
     "Shared with me" : "V souporabi z mano",
-    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
-    "Trusted senders" : "Zaupanja vredni pošiljatelji",
-    "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME",
+    "Security" : "Varnostna opozorila",
+    "Manage certificates" : "Upravljanje s potrdili",
     "About" : "O meni",
     "Keyboard shortcuts" : "Tipkovne bližnjice",
     "Compose new message" : "Novo sporočilo",
@@ -543,6 +539,15 @@ OC.L10N.register(
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
     "Continue to %s" : "Nadaljuj na %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad."
+    "Put my text to the bottom of a reply instead of on top of it." : "Dodaj besedilo odgovora pod izvorno sporočilo in ne nad.",
+    "Accounts" : "Računi",
+    "Newest" : "Najnovejše",
+    "Oldest" : "Najstarejše",
+    "Use Gravatar and favicon avatars" : "Uporabi podobe Gravatar in Favicon",
+    "Register as application for mail links" : "Nastavi kot program za odpiranje povezav na poštne elektronske naslove",
+    "Data collection consent" : "Strinjanje z zbiranjem podatkov",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Program lahko zbira podatke o vaših pogostih dejanjih in na podlagi teh podatkov prilagaja delovanje vašemu načinu uporabe. Podatki se shranjujejo le krajevno.",
+    "Trusted senders" : "Zaupanja vredni pošiljatelji",
+    "Manage S/MIME certificates" : "Upravljanje s potrdili S/MIME"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
