@@ -12,6 +12,9 @@ OC.L10N.register(
     "Signature" : "Potpis",
     "Cancel" : "Otkaži",
     "General" : "Opšte",
+    "Appearance" : "Izgled",
+    "Newest first" : "Prvo novije",
+    "Oldest first" : "prvo starije",
     "About" : "O programu",
     "Delete" : "Delete",
     "Search" : "Search",
