@@ -66,18 +66,16 @@ OC.L10N.register(
     "Cancel" : "Avbryt",
     "Could not update preference" : "Kunde inte uppdatera inställningar",
     "Mail settings" : "E-postinställningar",
-    "Accounts" : "Konton",
-    "Add mail account" : "Lägg till e-postkonto",
     "General" : "Allmänt",
+    "Add mail account" : "Lägg till e-postkonto",
+    "Appearance" : "Utseende",
     "Layout" : "Layout",
     "Sorting" : "Sortering",
-    "Newest" : "Nyast",
-    "Oldest" : "Äldst",
-    "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
-    "Register as application for mail links" : "Registrera som app för e-postlänkar",
+    "Newest first" : "Nyast först",
+    "Oldest first" : "Äldst först",
     "Register" : "Registrera",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
-    "Trusted senders" : "Betrodda avsändare",
+    "Security" : "Säkerhet",
+    "Manage certificates" : "Hantera certifikat",
     "About" : "Om",
     "Keyboard shortcuts" : "Tangentbordsgenvägar",
     "Compose new message" : "Skapa nytt meddelande",
@@ -386,6 +384,13 @@ OC.L10N.register(
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
     "Continue to %s" : "Fortsätt till %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp."
+    "Put my text to the bottom of a reply instead of on top of it." : "Infoga min text längst ner i ett svar i stället för längst upp.",
+    "Accounts" : "Konton",
+    "Newest" : "Nyast",
+    "Oldest" : "Äldst",
+    "Use Gravatar and favicon avatars" : "Använd Gravatar och favicon som profilbild",
+    "Register as application for mail links" : "Registrera som app för e-postlänkar",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Låt appen samla in data om dina interaktioner. Baserat på denna information kommer appen att anpassas till dina preferenser. Uppgifterna lagras endast lokalt.",
+    "Trusted senders" : "Betrodda avsändare"
 },
 "nplurals=2; plural=(n != 1);");
