@@ -19,9 +19,12 @@ OC.L10N.register(
     "Change name" : "เปลี่ยนชื่อ",
     "Email address" : "ที่อยู่อีเมล",
     "Cancel" : "ยกเลิก",
-    "Accounts" : "บัญชี",
     "General" : "ทั่วไป",
+    "Appearance" : "ลักษณะที่ปรากฏ",
+    "Newest first" : "ใหม่ที่สุดก่อน",
+    "Oldest first" : "เก่าที่สุดก่อน",
     "Register" : "ลงทะเบียน",
+    "Security" : "ความปลอดภัย",
     "About" : "เกี่ยวกับ",
     "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
     "Archive" : "ที่เก็บถาวร",
@@ -106,6 +109,7 @@ OC.L10N.register(
     "Error loading message" : "เกิดข้อผิดพลาดขณะโหลดข้อความ",
     "Redirect" : "เปลี่ยนเส้นทาง",
     "The link leads to %s" : "ลิงก์จะนำไปยัง %s",
-    "Continue to %s" : "ดำเนินการต่อไปที่ %s"
+    "Continue to %s" : "ดำเนินการต่อไปที่ %s",
+    "Accounts" : "บัญชี"
 },
 "nplurals=1; plural=0;");
