@@ -108,39 +108,30 @@ OC.L10N.register(
     "Add alias" : "ئالياس قوشۇڭ",
     "Create alias" : "Alias قۇر",
     "Cancel" : "ۋاز كەچ",
-    "Search in the body of messages in priority Inbox" : "مۇھىم خەت ساندۇقىدىكى ئۇچۇرلارنىڭ گەۋدىسىدىن ئىزدەڭ",
     "Activate" : "ئاكتىپلاش",
-    "Mark as important" : "مۇھىم دەپ بەلگە قويۇڭ",
     "Remind about messages that require a reply but received none" : "جاۋاب تەلەپ قىلىدىغان ، ئەمما تاپشۇرۇۋالمىغان ئۇچۇرلارنى ئەسكەرتىڭ",
-    "Use internal addresses" : "ئىچكى ئادرېسنى ئىشلىتىڭ",
     "Could not update preference" : "مايىللىقنى يېڭىلىيالمىدى",
     "Mail settings" : "خەت تەڭشەكلىرى",
-    "Accounts" : "ھېسابات",
+    "General" : "ئادەتتىكى",
     "Add mail account" : "خەت ھېساباتى قوشۇڭ",
     "Settings for:" : "تەڭشەكلەر:",
-    "General" : "ئادەتتىكى",
+    "Appearance" : "كۆرۈنۈش",
     "Layout" : "Layout",
     "List" : "تىزىملىك",
+    "Vertical split" : "ۋېرتىكال بۆلۈنۈش",
     "Horizontal split" : "توغرىسىغا بۆلۈنگەن",
     "Sorting" : "تەرتىپلەش",
-    "Newest" : "ئەڭ يېڭى",
-    "Oldest" : "ئەڭ كونا",
-    "Reply text position" : "تېكىست ئورنىغا جاۋاب بېرىڭ",
+    "Newest first" : "ئەڭ يېڭى",
+    "Oldest first" : "ئەڭ كونا",
     "Search in body" : "بەدەندە ئىزدەش",
     "Gravatar settings" : "Gravatar settings",
-    "Use Gravatar and favicon avatars" : "Gravatar ۋە favicon باش سۈرىتىنى ئىشلىتىڭ",
     "Mailto" : "Mailto",
-    "Register as application for mail links" : "خەت ئۇلانمىسىغا ئىلتىماس قىلىڭ",
     "Register" : "تىزىملىتىڭ",
     "Shared with me" : "مەن بىلەن ئورتاقلاشتى",
     "Privacy and security" : "مەخپىيەتلىك ۋە بىخەتەرلىك",
-    "Data collection consent" : "ئۇچۇر توپلاش ئىجازەتنامىسى",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "بۇ دېتالنىڭ ئۆز-ئارا تەسىرلىشىڭىزگە مۇناسىۋەتلىك ئۇچۇرلارنى توپلىشىغا يول قويۇڭ. بۇ سانلىق مەلۇماتلارغا ئاساسەن ، ئەپ سىزنىڭ مايىللىقىڭىزغا ماسلىشىدۇ. بۇ سانلىق مەلۇماتلار پەقەت يەرلىكتە ساقلىنىدۇ.",
-    "Trusted senders" : "ئىشەنچلىك ئەۋەتكۈچىلەر",
-    "Internal addresses" : "ئىچكى ئادرېس",
+    "Security" : "بىخەتەرلىك",
     "Highlight external email addresses by enabling this feature, manage your internal addresses and domains to ensure recognized contacts stay unmarked." : "بۇ ئىقتىدارنى قوزغىتىش ئارقىلىق تاشقى ئېلېكترونلۇق خەت ئادرېسىنى گەۋدىلەندۈرۈڭ ، ئىچكى ئادرېسىڭىز ۋە تور دائىرىڭىزنى باشقۇرۇپ ، تونۇلغان ئالاقىنىڭ بەلگىسىز بولۇشىغا كاپالەتلىك قىلىڭ.",
     "S/MIME" : "S / MIME",
-    "Manage S/MIME certificates" : "S / MIME گۇۋاھنامىسىنى باشقۇرۇش",
     "Mailvelope" : "Mailvelope",
     "Assistance features" : "ياردەم ئىقتىدارلىرى",
     "About" : "ھەققىدە",
@@ -265,6 +256,7 @@ OC.L10N.register(
     "Load more" : "تېخىمۇ كۆپ يۈكلەڭ",
     "Mark as unread" : "ئوقۇلمىغان دەپ بەلگە قويۇڭ",
     "Mark as read" : "ئوقۇغاندەك بەلگە قويۇڭ",
+    "Mark as important" : "مۇھىم دەپ بەلگە قويۇڭ",
     "Report this bug" : "بۇ خاتالىقنى دوكلات قىلىڭ",
     "Event created" : "پائالىيەت قۇرۇلدى",
     "Could not create event" : "ھادىسە قۇرالمىدى",
@@ -712,7 +704,19 @@ OC.L10N.register(
     "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
     "Continue to %s" : "داۋاملىق% s",
+    "Search in the body of messages in priority Inbox" : "مۇھىم خەت ساندۇقىدىكى ئۇچۇرلارنىڭ گەۋدىسىدىن ئىزدەڭ",
     "Put my text to the bottom of a reply instead of on top of it." : "تېكىستنى ئۇنىڭ ئورنىغا جاۋابنىڭ ئاستىغا قويۇڭ.",
-    "Vertical split" : "ۋېرتىكال بۆلۈنۈش"
+    "Use internal addresses" : "ئىچكى ئادرېسنى ئىشلىتىڭ",
+    "Accounts" : "ھېسابات",
+    "Newest" : "ئەڭ يېڭى",
+    "Oldest" : "ئەڭ كونا",
+    "Reply text position" : "تېكىست ئورنىغا جاۋاب بېرىڭ",
+    "Use Gravatar and favicon avatars" : "Gravatar ۋە favicon باش سۈرىتىنى ئىشلىتىڭ",
+    "Register as application for mail links" : "خەت ئۇلانمىسىغا ئىلتىماس قىلىڭ",
+    "Data collection consent" : "ئۇچۇر توپلاش ئىجازەتنامىسى",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "بۇ دېتالنىڭ ئۆز-ئارا تەسىرلىشىڭىزگە مۇناسىۋەتلىك ئۇچۇرلارنى توپلىشىغا يول قويۇڭ. بۇ سانلىق مەلۇماتلارغا ئاساسەن ، ئەپ سىزنىڭ مايىللىقىڭىزغا ماسلىشىدۇ. بۇ سانلىق مەلۇماتلار پەقەت يەرلىكتە ساقلىنىدۇ.",
+    "Trusted senders" : "ئىشەنچلىك ئەۋەتكۈچىلەر",
+    "Internal addresses" : "ئىچكى ئادرېس",
+    "Manage S/MIME certificates" : "S / MIME گۇۋاھنامىسىنى باشقۇرۇش"
 },
 "nplurals=2; plural=(n != 1);");
