@@ -47,15 +47,14 @@ OC.L10N.register(
     "Email address" : "Địa chỉ thư điện tử",
     "Add alias" : "Thêm bí danh",
     "Cancel" : "Hủy bỏ",
-    "Accounts" : "Tài khoản",
-    "Add mail account" : "Thêm tài khoản mail",
     "General" : "Tổng hợp",
+    "Add mail account" : "Thêm tài khoản mail",
+    "Appearance" : "Giao diện",
     "List" : "Danh sách",
-    "Use Gravatar and favicon avatars" : "Sử dụng hình đại diện Gravatar và favicon",
-    "Register as application for mail links" : "Đăng ký làm ứng dụng cho các liên kết gửi thư",
+    "Newest first" : "Mới nhất trước",
+    "Oldest first" : "Cũ nhất trước",
     "Register" : "Đăng ký",
-    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
-    "Trusted senders" : "Người gửi đáng tin cậy",
+    "Security" : "Bảo mật",
     "About" : "Giới thiệu",
     "Keyboard shortcuts" : "Phím tắt",
     "Compose new message" : "Soạn tin nhăn mơi",
@@ -285,6 +284,11 @@ OC.L10N.register(
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
     "Continue to %s" : "Tiếp tục %s",
-    "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư."
+    "Put my text to the bottom of a reply instead of on top of it." : "Đặt văn bản ở cuối thư trả lời thay vì ở đầu thư.",
+    "Accounts" : "Tài khoản",
+    "Use Gravatar and favicon avatars" : "Sử dụng hình đại diện Gravatar và favicon",
+    "Register as application for mail links" : "Đăng ký làm ứng dụng cho các liên kết gửi thư",
+    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Cho phép ứng dụng thu thập dữ liệu về các tương tác của bạn. Dựa trên dữ liệu này, ứng dụng sẽ điều chỉnh theo sở thích của bạn. Dữ liệu sẽ chỉ được lưu trữ trên máy của bạn.",
+    "Trusted senders" : "Người gửi đáng tin cậy"
 },
 "nplurals=1; plural=0;");
