@@ -22,31 +22,33 @@ class Version4000Date20240716172702 extends SimpleMigrationStep {
 	 * @param array $options
 	 * @return ISchemaWrapper
 	 */
+	#[\Override]
 	public function changeSchema(IOutput $output, Closure $schemaClosure, array $options): ?ISchemaWrapper {
-		/** @var ISchemaWrapper $schema */
 		$schema = $schemaClosure();
-		$table = $schema->createTable('mail_internal_address');
 
-		$table->addColumn('id', Types::INTEGER, [
-			'autoincrement' => true,
-			'notnull' => true,
-			'length' => 4,
-		]);
-		$table->addColumn('address', Types::STRING, [
-			'notnull' => true,
-			'length' => 255,
-		]);
-		$table->addColumn('type', Types::STRING, [
-			'notnull' => true,
-			'length' => 64,
-		]);
-		$table->addColumn('user_id', Types::STRING, [
-			'notnull' => true,
-			'length' => 64,
-		]);
-		$table->setPrimaryKey(['id']);
-		$table->addUniqueIndex(['address', 'user_id'], 'mail_internal_address_uniq');
-		
+		if (!$schema->hasTable('mail_internal_address')) {
+			$table = $schema->createTable('mail_internal_address');
+			$table->addColumn('id', Types::INTEGER, [
+				'autoincrement' => true,
+				'notnull' => true,
+				'length' => 4,
+			]);
+			$table->addColumn('address', Types::STRING, [
+				'notnull' => true,
+				'length' => 255,
+			]);
+			$table->addColumn('type', Types::STRING, [
+				'notnull' => true,
+				'length' => 64,
+			]);
+			$table->addColumn('user_id', Types::STRING, [
+				'notnull' => true,
+				'length' => 64,
+			]);
+			$table->setPrimaryKey(['id']);
+			$table->addUniqueIndex(['address', 'user_id'], 'mail_internal_address_uniq');
+		}
+
 		return $schema;
 	}
 
